@@ -27,12 +27,14 @@ cmd = [
   '--max-count=200',
   '--pretty=tformat:%cd  %an  <%ae>%n%n  %s%n%w(0,0,2)%+b',
 ]
-with open(os.path.join(os.getenv('MESON_DIST_ROOT'), 'ChangeLog'), mode='w') as logfile:
+# MESON_PROJECT_DIST_ROOT is set only if meson.version() >= 0.58.0.
+project_dist_root = os.getenv('MESON_PROJECT_DIST_ROOT', os.getenv('MESON_DIST_ROOT'))
+with open(os.path.join(project_dist_root, 'ChangeLog'), mode='w') as logfile:
   result = subprocess.run(cmd, stdout=logfile)
 
 # Distribute the libstdc++.tag file in addition to the files in the local git clone.
 # shutil.copy2() copies timestamps and some other file metadata.
 shutil.copy2(os.path.join(root_build_dir, 'libstdc++.tag'),
-             os.path.join(os.getenv('MESON_DIST_ROOT'), 'doctags'))
+             os.path.join(project_dist_root, 'doctags'))
 
 sys.exit(result.returncode)
